package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.EmsFacs;

import java.util.List;

/**
 * 能源设施/系统Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
public interface EmsFacsMapper {
    /**
     * 查询能源设施/系统
     *
     * @param id 能源设施/系统主键
     * @return 能源设施/系统
     */
    EmsFacs selectEmsFacsById(Long id);

    /**
     * 查询能源设施/系统
     *
     * @param code 能源设施/系统主键
     * @return 能源设施/系统
     */
    EmsFacs selectEmsFacsByCode(String code);

    /**
     * 查询能源设施/系统列表
     *
     * @param emsFacs 能源设施/系统
     * @return 能源设施/系统集合
     */
    List<EmsFacs> selectEmsFacsList(EmsFacs emsFacs);

    /**
     * 新增能源设施/系统
     *
     * @param emsFacs 能源设施/系统
     * @return 结果
     */
    int insertEmsFacs(EmsFacs emsFacs);

    /**
     * 修改能源设施/系统
     *
     * @param emsFacs 能源设施/系统
     * @return 结果
     */
    int updateEmsFacs(EmsFacs emsFacs);

    /**
     * 删除能源设施/系统
     *
     * @param id 能源设施/系统主键
     * @return 结果
     */
    int deleteEmsFacsById(Long id);

    /**
     * 批量删除能源设施/系统
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteEmsFacsByIds(Long[] ids);
}
