package com.ruoyi.ems.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.EmsFacs;
import com.ruoyi.ems.service.IEmsFacsService;

import io.swagger.annotations.Api;

/**
 * 能源设施/系统Controller
 *
 * @author ruoyi
 * @date 2024-07-10
 */
@RestController
@RequestMapping("/basecfg/emsfacs")
@Api(value = "EmsFacsController", description = "能源设施管理")
public class EmsFacsController extends BaseController
{
    @Autowired
    private IEmsFacsService emsFacsService;

    /**
     * 查询能源设施/系统列表
     */
    @RequiresPermissions("basecfg:emsfacs:list")
    @GetMapping("/list")
    public TableDataInfo list(EmsFacs emsFacs)
    {
        startPage();
        List<EmsFacs> list = emsFacsService.selectEmsFacsList(emsFacs);
        return getDataTable(list);
    }

    /**
     * 导出能源设施/系统列表
     */
    @RequiresPermissions("basecfg:emsfacs:export")
    @Log(title = "能源设施/系统", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsFacs emsFacs)
    {
        List<EmsFacs> list = emsFacsService.selectEmsFacsList(emsFacs);
        ExcelUtil<EmsFacs> util = new ExcelUtil<EmsFacs>(EmsFacs.class);
        util.exportExcel(response, list, "能源设施/系统数据");
    }

    /**
     * 获取能源设施/系统详细信息
     */
    @RequiresPermissions("basecfg:emsfacs:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(emsFacsService.selectEmsFacsById(id));
    }

    /**
     * 新增能源设施/系统
     */
    @RequiresPermissions("basecfg:emsfacs:add")
    @Log(title = "能源设施/系统", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsFacs emsFacs)
    {
        return toAjax(emsFacsService.insertEmsFacs(emsFacs));
    }

    /**
     * 修改能源设施/系统
     */
    @RequiresPermissions("basecfg:emsfacs:edit")
    @Log(title = "能源设施/系统", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsFacs emsFacs)
    {
        return toAjax(emsFacsService.updateEmsFacs(emsFacs));
    }

    /**
     * 删除能源设施/系统
     */
    @RequiresPermissions("basecfg:emsfacs:remove")
    @Log(title = "能源设施/系统", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(emsFacsService.deleteEmsFacsByIds(ids));
    }

    /**
     * 获取所有能源设施/系统列表
     * @return 能源设施/系统列表
     */
    @GetMapping("/listall")
    public AjaxResult listAll(@RequestParam(name = "refArea", required = false) String refArea) {
        EmsFacs emsFacs = new EmsFacs();

        if (StringUtils.isNotBlank(refArea)) {
            emsFacs.setRefArea(refArea);
        }

        return success(emsFacsService.selectEmsFacsList(emsFacs));
    }

    /**
     * 网-服务区日功率指标
     *
     * @param areaCode
     * @return
     */
    @GetMapping("/area/day/power/index")
    public AjaxResult qryAreaDayPowerIndex(@RequestParam("areaCode") String areaCode) {
        return success(emsFacsService.qryAreaDayPowerIndex(areaCode));
    }
}
